@@ -192,17 +192,6 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
         else:  # <v39 - dict  todo: remove when 39+ is wide in production
             return parameters
 
-    @property
-    def currentWorkflow(self):
-        j = self.json()
-        #TODO: FIXME: get rid of old API when its support will be removed
-        # We could get {} or None for both together. Dependant code expects dict(), so, returning dict.
-        if j.get('currentWorkflow', {}):
-            return j.get('currentWorkflow', {})
-        elif j.get('workflowsInfo', {}).get('currentWorkflow', {}):
-            return j.get('workflowsInfo', {}).get('currentWorkflow', {})
-        else:
-            return {}
 
     def __getattr__(self, key):
         if key in ['instanceId', ]:
@@ -211,14 +200,41 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
             log.debug('Checking instance status')
             return self.ready()
         #TODO: FIXME: old API support: remove when its support will be removed on server
-        elif key in ['workflowHistory', 'scheduledWorkflows', 'availableWorkflows']:
+
+        elif key in ['scheduledWorkflows', 'availableWorkflows']:
             log.debug('Getting instance workflow attribute: %s' % key)
             j = self.json()
-            old_api_value = j.get(key)
-            new_api_value = j.get('workflowsInfo', {}).get(key, False)
+            api_value = j.get('workflowsInfo', {}).get(key, False)
+            atr = api_value or []
+            log.debug(atr)
+            return atr
+        elif key == 'workflowHistory':
+            log.debug('Getting instance workflow attribute: %s' % key)
+            j = self.json()
+
+            old_api_value = j.get('workflowsInfo', {}).get(key, False)
+
+            if not old_api_value :
+                new_api_value = self._router.get_instance_workflowhistory(org_id=self.organizationId, instance_id=self.instanceId).json()
+            else:
+                new_api_value = False
+
             atr = new_api_value or old_api_value or []
             log.debug(atr)
             return atr
+        elif key == 'workflowsInfo':
+            log.debug('Getting instance attribute: %s' % key)
+            j = self.json()
+            api_value = j.get('workflowsInfo', False)
+            old_workflowHistory = api_value.get('workflowHistory', False)
+
+            if not old_workflowHistory:
+                api_value['workflowHistory'] = self._router.get_instance_workflowhistory(org_id=self.organizationId, instance_id=self.instanceId).json()
+
+            atr = api_value or {}
+            log.debug(atr)
+            return atr
+
         else:
             log.debug('Getting instance attribute: %s' % key)
             atr = self.json()[key]
@@ -256,11 +272,12 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
         # noinspection PyAttributeOutsideInit
         self.__last_read_time = time.time()
         self.__cached_json = self._router.get_instance(org_id=self.organizationId, instance_id=self.instanceId).json()
+
         return self.__cached_json
 
     @staticmethod
     def new(router, application, revision=None, environment=None, name=None, parameters=None,
-            submodules=None, destroyInterval=None):
+            submodules=None, destroyInterval=None, manifestVersion=None):
 
         if not environment:
             environment = application.organization.defaultEnvironment
@@ -282,6 +299,8 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
             conf['destroyInterval'] = int(destroyInterval)
         if revision:
             conf['revisionId'] = revision.id
+        if manifestVersion:
+            conf['version'] = int(manifestVersion)
         conf['submodules'] = submodules or {}
         log.info(("Starting instance: %s\n"
                   "    Application: id=%s\n"
@@ -404,9 +423,9 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
     def reconfigure(self, revision=None, parameters=None, submodules=None, manifestVersion=None):
         # if no parameters are specified, use an alternative, more concise API route
         if not revision \
-           and parameters is None \
-           and not submodules \
-           and not manifestVersion:
+                and parameters is None \
+                and not submodules \
+                and not manifestVersion:
             resp = self._router.post_instance_reconfigure(org_id=self.organizationId, instance_id=self.instanceId)
             return resp.json()
 
@@ -497,11 +516,6 @@ class Instance(Entity, ServiceMixin, InstanceRouter):
                 return time.gmtime(t/1000)
             return None
         try:
-            if self.currentWorkflow:
-                cw_started_at = self.currentWorkflow.get('startedAt')
-                if cw_started_at:
-                    return parse_time(cw_started_at)
-
             max_wf_started_at = max([i.get('startedAt') for i in self.workflowHistory])
             return parse_time(max_wf_started_at)
         except ValueError:
@@ -659,4 +673,4 @@ class ActivityLog(object):
         not_found('nothing within boundaries')
 
 
-activityLog = ActivityLog  # todo: remove this
\ No newline at end of file
+activityLog = ActivityLog  # todo: remove this
