@@ -252,12 +252,12 @@ class Organization(Entity, InstanceRouter):
 # INSTANCE
 
     def create_instance(self, application, revision=None, environment=None, name=None, parameters=None, submodules=None,
-                        destroyInterval=None):
+                        destroyInterval=None, manifestVersion=None):
         """ Launches instance in application and returns Instance object.
         """
         from qubell.api.private.instance import Instance
         return Instance.new(self._router, application, revision, environment, name,
-                            parameters, submodules, destroyInterval)
+                            parameters, submodules, destroyInterval, manifestVersion=manifestVersion)
 
     def get_instance(self, id=None, name=None):
         """ Get instance object by name or id.
